/********************************************************************************
** Form generated from reading UI file 'kganttdatetimetimelinedialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KGANTTDATETIMETIMELINEDIALOG_H
#define UI_KGANTTDATETIMETIMELINEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kganttpenstylecombobox.h"

namespace KGantt {

class Ui_DateTimeTimeLineDialog
{
public:
    QVBoxLayout *verticalLayout_3;
    QWidget *widget;
    QVBoxLayout *verticalLayout;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *timeLineDisabled;
    QRadioButton *foreground;
    QRadioButton *background;
    QCheckBox *useCustomPen;
    QHBoxLayout *horizontalLayout_5;
    QHBoxLayout *horizontalLayout;
    QLabel *label_4;
    KGantt::PenStyleComboBox *penStyle;
    QLabel *label_3;
    QSpinBox *penWidth;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_5;
    QToolButton *openColorDialog;
    QSpacerItem *horizontalSpacer_4;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QTimeEdit *updateInterval;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QDateTimeEdit *dateTime;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer;
    QFrame *line;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *KGantt__DateTimeTimeLineDialog)
    {
        if (KGantt__DateTimeTimeLineDialog->objectName().isEmpty())
            KGantt__DateTimeTimeLineDialog->setObjectName(QString::fromUtf8("KGantt__DateTimeTimeLineDialog"));
        KGantt__DateTimeTimeLineDialog->resize(405, 335);
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KGantt__DateTimeTimeLineDialog->sizePolicy().hasHeightForWidth());
        KGantt__DateTimeTimeLineDialog->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(KGantt__DateTimeTimeLineDialog);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        widget = new QWidget(KGantt__DateTimeTimeLineDialog);
        widget->setObjectName(QString::fromUtf8("widget"));
        verticalLayout = new QVBoxLayout(widget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        timeLineDisabled = new QRadioButton(widget);
        timeLineDisabled->setObjectName(QString::fromUtf8("timeLineDisabled"));
        timeLineDisabled->setChecked(true);

        verticalLayout_2->addWidget(timeLineDisabled);

        foreground = new QRadioButton(widget);
        foreground->setObjectName(QString::fromUtf8("foreground"));

        verticalLayout_2->addWidget(foreground);

        background = new QRadioButton(widget);
        background->setObjectName(QString::fromUtf8("background"));

        verticalLayout_2->addWidget(background);


        verticalLayout->addLayout(verticalLayout_2);

        useCustomPen = new QCheckBox(widget);
        useCustomPen->setObjectName(QString::fromUtf8("useCustomPen"));

        verticalLayout->addWidget(useCustomPen);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label_4 = new QLabel(widget);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        horizontalLayout->addWidget(label_4);

        penStyle = new KGantt::PenStyleComboBox(widget);
        penStyle->setObjectName(QString::fromUtf8("penStyle"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(penStyle->sizePolicy().hasHeightForWidth());
        penStyle->setSizePolicy(sizePolicy1);
        penStyle->setMinimumSize(QSize(87, 0));

        horizontalLayout->addWidget(penStyle);

        label_3 = new QLabel(widget);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label_3);

        penWidth = new QSpinBox(widget);
        penWidth->setObjectName(QString::fromUtf8("penWidth"));

        horizontalLayout->addWidget(penWidth);


        horizontalLayout_5->addLayout(horizontalLayout);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));

        horizontalLayout_5->addLayout(horizontalLayout_4);

        label_5 = new QLabel(widget);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        horizontalLayout_5->addWidget(label_5);

        openColorDialog = new QToolButton(widget);
        openColorDialog->setObjectName(QString::fromUtf8("openColorDialog"));
        QSizePolicy sizePolicy2(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(openColorDialog->sizePolicy().hasHeightForWidth());
        openColorDialog->setSizePolicy(sizePolicy2);
        openColorDialog->setText(QString::fromUtf8("..."));

        horizontalLayout_5->addWidget(openColorDialog);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_5);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_2 = new QLabel(widget);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        updateInterval = new QTimeEdit(widget);
        updateInterval->setObjectName(QString::fromUtf8("updateInterval"));
        updateInterval->setCurrentSection(QDateTimeEdit::HourSection);
        updateInterval->setDisplayFormat(QString::fromUtf8("HH.mm.ss"));

        gridLayout->addWidget(updateInterval, 0, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        label = new QLabel(widget);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 1, 0, 1, 1);

        dateTime = new QDateTimeEdit(widget);
        dateTime->setObjectName(QString::fromUtf8("dateTime"));
        dateTime->setCalendarPopup(true);

        gridLayout->addWidget(dateTime, 1, 1, 1, 2);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 1, 3, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        line = new QFrame(widget);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line);


        verticalLayout_3->addWidget(widget);

        buttonBox = new QDialogButtonBox(KGantt__DateTimeTimeLineDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(updateInterval);
        label->setBuddy(dateTime);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(timeLineDisabled, foreground);
        QWidget::setTabOrder(foreground, background);
        QWidget::setTabOrder(background, useCustomPen);
        QWidget::setTabOrder(useCustomPen, penStyle);
        QWidget::setTabOrder(penStyle, penWidth);
        QWidget::setTabOrder(penWidth, openColorDialog);
        QWidget::setTabOrder(openColorDialog, updateInterval);
        QWidget::setTabOrder(updateInterval, dateTime);

        retranslateUi(KGantt__DateTimeTimeLineDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), KGantt__DateTimeTimeLineDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), KGantt__DateTimeTimeLineDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(KGantt__DateTimeTimeLineDialog);
    } // setupUi

    void retranslateUi(QDialog *KGantt__DateTimeTimeLineDialog)
    {
        KGantt__DateTimeTimeLineDialog->setWindowTitle(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "Timeline Settings", nullptr));
        timeLineDisabled->setText(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "Timeline disabled", nullptr));
        foreground->setText(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "Draw line in the foreground", nullptr));
        background->setText(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "Draw line in the background", nullptr));
#if QT_CONFIG(tooltip)
        useCustomPen->setToolTip(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "<html><head/><body><p>When deactivated, a cosmetic pen with <span style=\" font-style:italic;\">highligt</span> color will be used.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        useCustomPen->setText(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "Use Custom Pen", nullptr));
        label_4->setText(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "Style:", nullptr));
        label_3->setText(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "Width:", nullptr));
        label_5->setText(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "Color:", nullptr));
        label_2->setText(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "Update frequency:", nullptr));
#if QT_CONFIG(tooltip)
        updateInterval->setToolTip(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "<html><head/><body><p>Periodically moves the timeline to current datetime. If set to zero, the F<span style=\" font-style:italic;\">ixed datetime</span> is used and the timeline will not move.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label->setText(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "Fixed time:", nullptr));
#if QT_CONFIG(tooltip)
        dateTime->setToolTip(QCoreApplication::translate("KGantt::DateTimeTimeLineDialog", "<html><head/><body><p>Draws the timeline at this datetime. Only used if <span style=\" font-style:italic;\">Update frequency</span> is zero.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

} // namespace KGantt

namespace KGantt {
namespace Ui {
    class DateTimeTimeLineDialog: public Ui_DateTimeTimeLineDialog {};
} // namespace Ui
} // namespace KGantt

#endif // UI_KGANTTDATETIMETIMELINEDIALOG_H
