/****************************************************************************
** Meta object code from reading C++ file 'kganttgraphicsscene.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdiagram-2.8.0/src/KGantt/kganttgraphicsscene.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kganttgraphicsscene.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KGantt__GraphicsScene_t {
    QByteArrayData data[30];
    char stringdata0[438];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KGantt__GraphicsScene_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KGantt__GraphicsScene_t qt_meta_stringdata_KGantt__GraphicsScene = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KGantt::GraphicsScene"
QT_MOC_LITERAL(1, 22, 11), // "gridChanged"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 7), // "clicked"
QT_MOC_LITERAL(4, 43, 11), // "QModelIndex"
QT_MOC_LITERAL(5, 55, 5), // "index"
QT_MOC_LITERAL(6, 61, 12), // "qrealClicked"
QT_MOC_LITERAL(7, 74, 7), // "entered"
QT_MOC_LITERAL(8, 82, 7), // "pressed"
QT_MOC_LITERAL(9, 90, 8), // "setModel"
QT_MOC_LITERAL(10, 99, 19), // "QAbstractItemModel*"
QT_MOC_LITERAL(11, 119, 23), // "setSummaryHandlingModel"
QT_MOC_LITERAL(12, 143, 20), // "QAbstractProxyModel*"
QT_MOC_LITERAL(13, 164, 18), // "setConstraintModel"
QT_MOC_LITERAL(14, 183, 16), // "ConstraintModel*"
QT_MOC_LITERAL(15, 200, 12), // "setRootIndex"
QT_MOC_LITERAL(16, 213, 3), // "idx"
QT_MOC_LITERAL(17, 217, 17), // "setSelectionModel"
QT_MOC_LITERAL(18, 235, 20), // "QItemSelectionModel*"
QT_MOC_LITERAL(19, 256, 14), // "selectionmodel"
QT_MOC_LITERAL(20, 271, 11), // "setReadOnly"
QT_MOC_LITERAL(21, 283, 19), // "slotConstraintAdded"
QT_MOC_LITERAL(22, 303, 18), // "KGantt::Constraint"
QT_MOC_LITERAL(23, 322, 21), // "slotConstraintRemoved"
QT_MOC_LITERAL(24, 344, 15), // "slotGridChanged"
QT_MOC_LITERAL(25, 360, 20), // "slotSelectionChanged"
QT_MOC_LITERAL(26, 381, 14), // "QItemSelection"
QT_MOC_LITERAL(27, 396, 8), // "selected"
QT_MOC_LITERAL(28, 405, 10), // "deselected"
QT_MOC_LITERAL(29, 416, 21) // "selectionModelChanged"

    },
    "KGantt::GraphicsScene\0gridChanged\0\0"
    "clicked\0QModelIndex\0index\0qrealClicked\0"
    "entered\0pressed\0setModel\0QAbstractItemModel*\0"
    "setSummaryHandlingModel\0QAbstractProxyModel*\0"
    "setConstraintModel\0ConstraintModel*\0"
    "setRootIndex\0idx\0setSelectionModel\0"
    "QItemSelectionModel*\0selectionmodel\0"
    "setReadOnly\0slotConstraintAdded\0"
    "KGantt::Constraint\0slotConstraintRemoved\0"
    "slotGridChanged\0slotSelectionChanged\0"
    "QItemSelection\0selected\0deselected\0"
    "selectionModelChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KGantt__GraphicsScene[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x06 /* Public */,
       3,    1,   95,    2, 0x06 /* Public */,
       6,    1,   98,    2, 0x06 /* Public */,
       7,    1,  101,    2, 0x06 /* Public */,
       8,    1,  104,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,  107,    2, 0x0a /* Public */,
      11,    1,  110,    2, 0x0a /* Public */,
      13,    1,  113,    2, 0x0a /* Public */,
      15,    1,  116,    2, 0x0a /* Public */,
      17,    1,  119,    2, 0x0a /* Public */,
      20,    1,  122,    2, 0x0a /* Public */,
      21,    1,  125,    2, 0x08 /* Private */,
      23,    1,  128,    2, 0x08 /* Private */,
      24,    0,  131,    2, 0x08 /* Private */,
      25,    2,  132,    2, 0x08 /* Private */,
      29,    1,  137,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 4,    5,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void, 0x80000000 | 4,   16,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 22,    2,
    QMetaType::Void, 0x80000000 | 22,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 26, 0x80000000 | 26,   27,   28,
    QMetaType::Void, 0x80000000 | 10,    2,

       0        // eod
};

void KGantt::GraphicsScene::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<GraphicsScene *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->gridChanged(); break;
        case 1: _t->clicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 2: _t->qrealClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 3: _t->entered((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 4: _t->pressed((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 5: _t->setModel((*reinterpret_cast< QAbstractItemModel*(*)>(_a[1]))); break;
        case 6: _t->setSummaryHandlingModel((*reinterpret_cast< QAbstractProxyModel*(*)>(_a[1]))); break;
        case 7: _t->setConstraintModel((*reinterpret_cast< ConstraintModel*(*)>(_a[1]))); break;
        case 8: _t->setRootIndex((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 9: _t->setSelectionModel((*reinterpret_cast< QItemSelectionModel*(*)>(_a[1]))); break;
        case 10: _t->setReadOnly((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->slotConstraintAdded((*reinterpret_cast< const KGantt::Constraint(*)>(_a[1]))); break;
        case 12: _t->slotConstraintRemoved((*reinterpret_cast< const KGantt::Constraint(*)>(_a[1]))); break;
        case 13: _t->slotGridChanged(); break;
        case 14: _t->slotSelectionChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 15: _t->selectionModelChanged((*reinterpret_cast< QAbstractItemModel*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (GraphicsScene::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsScene::gridChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (GraphicsScene::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsScene::clicked)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (GraphicsScene::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsScene::qrealClicked)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (GraphicsScene::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsScene::entered)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (GraphicsScene::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsScene::pressed)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KGantt::GraphicsScene::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsScene::staticMetaObject>(),
    qt_meta_stringdata_KGantt__GraphicsScene.data,
    qt_meta_data_KGantt__GraphicsScene,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KGantt::GraphicsScene::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGantt::GraphicsScene::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KGantt__GraphicsScene.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int KGantt::GraphicsScene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void KGantt::GraphicsScene::gridChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KGantt::GraphicsScene::clicked(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KGantt::GraphicsScene::qrealClicked(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KGantt::GraphicsScene::entered(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KGantt::GraphicsScene::pressed(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
