/****************************************************************************
** Meta object code from reading C++ file 'KChartPlotter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdiagram-2.8.0/src/KChart/Cartesian/KChartPlotter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KChartPlotter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KChart__Plotter_t {
    QByteArrayData data[13];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KChart__Plotter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KChart__Plotter_t qt_meta_stringdata_KChart__Plotter = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KChart::Plotter"
QT_MOC_LITERAL(1, 16, 22), // "connectAttributesModel"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 16), // "AttributesModel*"
QT_MOC_LITERAL(4, 57, 22), // "setDataBoundariesDirty"
QT_MOC_LITERAL(5, 80, 15), // "calcMergeRadius"
QT_MOC_LITERAL(6, 96, 18), // "useDataCompression"
QT_MOC_LITERAL(7, 115, 15), // "CompressionMode"
QT_MOC_LITERAL(8, 131, 21), // "mergeRadiusPercentage"
QT_MOC_LITERAL(9, 153, 5), // "SLOPE"
QT_MOC_LITERAL(10, 159, 8), // "DISTANCE"
QT_MOC_LITERAL(11, 168, 4), // "BOTH"
QT_MOC_LITERAL(12, 173, 4) // "NONE"

    },
    "KChart::Plotter\0connectAttributesModel\0"
    "\0AttributesModel*\0setDataBoundariesDirty\0"
    "calcMergeRadius\0useDataCompression\0"
    "CompressionMode\0mergeRadiusPercentage\0"
    "SLOPE\0DISTANCE\0BOTH\0NONE"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KChart__Plotter[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       2,   34, // properties
       1,   40, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x09 /* Protected */,
       4,    0,   32,    2, 0x09 /* Protected */,
       5,    0,   33,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       6, 0x80000000 | 7, 0x0009510b,
       8, QMetaType::QReal, 0x00095103,

 // enums: name, alias, flags, count, data
       7,    7, 0x0,    4,   45,

 // enum data: key, value
       9, uint(KChart::Plotter::SLOPE),
      10, uint(KChart::Plotter::DISTANCE),
      11, uint(KChart::Plotter::BOTH),
      12, uint(KChart::Plotter::NONE),

       0        // eod
};

void KChart::Plotter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Plotter *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->connectAttributesModel((*reinterpret_cast< AttributesModel*(*)>(_a[1]))); break;
        case 1: _t->setDataBoundariesDirty(); break;
        case 2: _t->calcMergeRadius(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AttributesModel* >(); break;
            }
            break;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Plotter *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< CompressionMode*>(_v) = _t->useDataCompression(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->mergeRadiusPercentage(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<Plotter *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUseDataCompression(*reinterpret_cast< CompressionMode*>(_v)); break;
        case 1: _t->setMergeRadiusPercentage(*reinterpret_cast< qreal*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KChart::Plotter::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractCartesianDiagram::staticMetaObject>(),
    qt_meta_stringdata_KChart__Plotter.data,
    qt_meta_data_KChart__Plotter,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KChart::Plotter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KChart::Plotter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KChart__Plotter.stringdata0))
        return static_cast<void*>(this);
    return AbstractCartesianDiagram::qt_metacast(_clname);
}

int KChart::Plotter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractCartesianDiagram::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
