/****************************************************************************
** Meta object code from reading C++ file 'KChartDiagramObserver.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdiagram-2.8.0/src/KChart/KChartDiagramObserver.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KChartDiagramObserver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KChart__DiagramObserver_t {
    QByteArrayData data[18];
    char stringdata0[313];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KChart__DiagramObserver_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KChart__DiagramObserver_t qt_meta_stringdata_KChart__DiagramObserver = {
    {
QT_MOC_LITERAL(0, 0, 23), // "KChart::DiagramObserver"
QT_MOC_LITERAL(1, 24, 16), // "diagramDestroyed"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 16), // "AbstractDiagram*"
QT_MOC_LITERAL(4, 59, 7), // "diagram"
QT_MOC_LITERAL(5, 67, 25), // "diagramAboutToBeDestroyed"
QT_MOC_LITERAL(6, 93, 18), // "diagramDataChanged"
QT_MOC_LITERAL(7, 112, 17), // "diagramDataHidden"
QT_MOC_LITERAL(8, 130, 24), // "diagramAttributesChanged"
QT_MOC_LITERAL(9, 155, 13), // "slotDestroyed"
QT_MOC_LITERAL(10, 169, 22), // "slotAboutToBeDestroyed"
QT_MOC_LITERAL(11, 192, 21), // "slotHeaderDataChanged"
QT_MOC_LITERAL(12, 214, 15), // "Qt::Orientation"
QT_MOC_LITERAL(13, 230, 15), // "slotDataChanged"
QT_MOC_LITERAL(14, 246, 11), // "QModelIndex"
QT_MOC_LITERAL(15, 258, 14), // "slotDataHidden"
QT_MOC_LITERAL(16, 273, 21), // "slotAttributesChanged"
QT_MOC_LITERAL(17, 295, 17) // "slotModelsChanged"

    },
    "KChart::DiagramObserver\0diagramDestroyed\0"
    "\0AbstractDiagram*\0diagram\0"
    "diagramAboutToBeDestroyed\0diagramDataChanged\0"
    "diagramDataHidden\0diagramAttributesChanged\0"
    "slotDestroyed\0slotAboutToBeDestroyed\0"
    "slotHeaderDataChanged\0Qt::Orientation\0"
    "slotDataChanged\0QModelIndex\0slotDataHidden\0"
    "slotAttributesChanged\0slotModelsChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KChart__DiagramObserver[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x06 /* Public */,
       5,    1,   87,    2, 0x06 /* Public */,
       6,    1,   90,    2, 0x06 /* Public */,
       7,    1,   93,    2, 0x06 /* Public */,
       8,    1,   96,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,   99,    2, 0x08 /* Private */,
      10,    0,  102,    2, 0x08 /* Private */,
      11,    3,  103,    2, 0x08 /* Private */,
      13,    2,  110,    2, 0x08 /* Private */,
      13,    0,  115,    2, 0x08 /* Private */,
      15,    0,  116,    2, 0x08 /* Private */,
      16,    0,  117,    2, 0x08 /* Private */,
      16,    2,  118,    2, 0x08 /* Private */,
      17,    0,  123,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::QObjectStar,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 14, 0x80000000 | 14,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14, 0x80000000 | 14,    2,    2,
    QMetaType::Void,

       0        // eod
};

void KChart::DiagramObserver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DiagramObserver *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->diagramDestroyed((*reinterpret_cast< AbstractDiagram*(*)>(_a[1]))); break;
        case 1: _t->diagramAboutToBeDestroyed((*reinterpret_cast< AbstractDiagram*(*)>(_a[1]))); break;
        case 2: _t->diagramDataChanged((*reinterpret_cast< AbstractDiagram*(*)>(_a[1]))); break;
        case 3: _t->diagramDataHidden((*reinterpret_cast< AbstractDiagram*(*)>(_a[1]))); break;
        case 4: _t->diagramAttributesChanged((*reinterpret_cast< AbstractDiagram*(*)>(_a[1]))); break;
        case 5: _t->slotDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 6: _t->slotAboutToBeDestroyed(); break;
        case 7: _t->slotHeaderDataChanged((*reinterpret_cast< Qt::Orientation(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 8: _t->slotDataChanged((*reinterpret_cast< QModelIndex(*)>(_a[1])),(*reinterpret_cast< QModelIndex(*)>(_a[2]))); break;
        case 9: _t->slotDataChanged(); break;
        case 10: _t->slotDataHidden(); break;
        case 11: _t->slotAttributesChanged(); break;
        case 12: _t->slotAttributesChanged((*reinterpret_cast< QModelIndex(*)>(_a[1])),(*reinterpret_cast< QModelIndex(*)>(_a[2]))); break;
        case 13: _t->slotModelsChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DiagramObserver::*)(AbstractDiagram * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DiagramObserver::diagramDestroyed)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DiagramObserver::*)(AbstractDiagram * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DiagramObserver::diagramAboutToBeDestroyed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DiagramObserver::*)(AbstractDiagram * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DiagramObserver::diagramDataChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DiagramObserver::*)(AbstractDiagram * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DiagramObserver::diagramDataHidden)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DiagramObserver::*)(AbstractDiagram * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DiagramObserver::diagramAttributesChanged)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KChart::DiagramObserver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KChart__DiagramObserver.data,
    qt_meta_data_KChart__DiagramObserver,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KChart::DiagramObserver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KChart::DiagramObserver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KChart__DiagramObserver.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KChart::DiagramObserver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void KChart::DiagramObserver::diagramDestroyed(AbstractDiagram * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KChart::DiagramObserver::diagramAboutToBeDestroyed(AbstractDiagram * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KChart::DiagramObserver::diagramDataChanged(AbstractDiagram * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KChart::DiagramObserver::diagramDataHidden(AbstractDiagram * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KChart::DiagramObserver::diagramAttributesChanged(AbstractDiagram * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
