/****************************************************************************
** Meta object code from reading C++ file 'kganttforwardingproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdiagram-2.8.0/src/KGantt/kganttforwardingproxymodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kganttforwardingproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KGantt__ForwardingProxyModel_t {
    QByteArrayData data[21];
    char stringdata0[370];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KGantt__ForwardingProxyModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KGantt__ForwardingProxyModel_t qt_meta_stringdata_KGantt__ForwardingProxyModel = {
    {
QT_MOC_LITERAL(0, 0, 28), // "KGantt::ForwardingProxyModel"
QT_MOC_LITERAL(1, 29, 25), // "sourceModelAboutToBeReset"
QT_MOC_LITERAL(2, 55, 0), // ""
QT_MOC_LITERAL(3, 56, 16), // "sourceModelReset"
QT_MOC_LITERAL(4, 73, 28), // "sourceLayoutAboutToBeChanged"
QT_MOC_LITERAL(5, 102, 19), // "sourceLayoutChanged"
QT_MOC_LITERAL(6, 122, 17), // "sourceDataChanged"
QT_MOC_LITERAL(7, 140, 11), // "QModelIndex"
QT_MOC_LITERAL(8, 152, 4), // "from"
QT_MOC_LITERAL(9, 157, 2), // "to"
QT_MOC_LITERAL(10, 160, 30), // "sourceColumnsAboutToBeInserted"
QT_MOC_LITERAL(11, 191, 3), // "idx"
QT_MOC_LITERAL(12, 195, 5), // "start"
QT_MOC_LITERAL(13, 201, 3), // "end"
QT_MOC_LITERAL(14, 205, 21), // "sourceColumnsInserted"
QT_MOC_LITERAL(15, 227, 29), // "sourceColumnsAboutToBeRemoved"
QT_MOC_LITERAL(16, 257, 20), // "sourceColumnsRemoved"
QT_MOC_LITERAL(17, 278, 27), // "sourceRowsAboutToBeInserted"
QT_MOC_LITERAL(18, 306, 18), // "sourceRowsInserted"
QT_MOC_LITERAL(19, 325, 26), // "sourceRowsAboutToBeRemoved"
QT_MOC_LITERAL(20, 352, 17) // "sourceRowsRemoved"

    },
    "KGantt::ForwardingProxyModel\0"
    "sourceModelAboutToBeReset\0\0sourceModelReset\0"
    "sourceLayoutAboutToBeChanged\0"
    "sourceLayoutChanged\0sourceDataChanged\0"
    "QModelIndex\0from\0to\0sourceColumnsAboutToBeInserted\0"
    "idx\0start\0end\0sourceColumnsInserted\0"
    "sourceColumnsAboutToBeRemoved\0"
    "sourceColumnsRemoved\0sourceRowsAboutToBeInserted\0"
    "sourceRowsInserted\0sourceRowsAboutToBeRemoved\0"
    "sourceRowsRemoved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KGantt__ForwardingProxyModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x09 /* Protected */,
       3,    0,   80,    2, 0x09 /* Protected */,
       4,    0,   81,    2, 0x09 /* Protected */,
       5,    0,   82,    2, 0x09 /* Protected */,
       6,    2,   83,    2, 0x09 /* Protected */,
      10,    3,   88,    2, 0x09 /* Protected */,
      14,    3,   95,    2, 0x09 /* Protected */,
      15,    3,  102,    2, 0x09 /* Protected */,
      16,    3,  109,    2, 0x09 /* Protected */,
      17,    3,  116,    2, 0x09 /* Protected */,
      18,    3,  123,    2, 0x09 /* Protected */,
      19,    3,  130,    2, 0x09 /* Protected */,
      20,    3,  137,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 7,    8,    9,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int,   11,   12,   13,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int,   11,   12,   13,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int,   11,   12,   13,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int,   11,   12,   13,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int,   11,   12,   13,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int,   11,   12,   13,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int,    2,   12,   13,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int,    2,   12,   13,

       0        // eod
};

void KGantt::ForwardingProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ForwardingProxyModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sourceModelAboutToBeReset(); break;
        case 1: _t->sourceModelReset(); break;
        case 2: _t->sourceLayoutAboutToBeChanged(); break;
        case 3: _t->sourceLayoutChanged(); break;
        case 4: _t->sourceDataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 5: _t->sourceColumnsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 6: _t->sourceColumnsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 7: _t->sourceColumnsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 8: _t->sourceColumnsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 9: _t->sourceRowsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 10: _t->sourceRowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 11: _t->sourceRowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 12: _t->sourceRowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KGantt::ForwardingProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractProxyModel::staticMetaObject>(),
    qt_meta_stringdata_KGantt__ForwardingProxyModel.data,
    qt_meta_data_KGantt__ForwardingProxyModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KGantt::ForwardingProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGantt::ForwardingProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KGantt__ForwardingProxyModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractProxyModel::qt_metacast(_clname);
}

int KGantt::ForwardingProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
