/****************************************************************************
** Meta object code from reading C++ file 'KChartWidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdiagram-2.8.0/src/KChart/KChartWidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KChartWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KChart__Widget_t {
    QByteArrayData data[18];
    char stringdata0[204];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KChart__Widget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KChart__Widget_t qt_meta_stringdata_KChart__Widget = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KChart::Widget"
QT_MOC_LITERAL(1, 15, 16), // "setGlobalLeading"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 4), // "left"
QT_MOC_LITERAL(4, 38, 3), // "top"
QT_MOC_LITERAL(5, 42, 5), // "right"
QT_MOC_LITERAL(6, 48, 6), // "bottom"
QT_MOC_LITERAL(7, 55, 20), // "setGlobalLeadingLeft"
QT_MOC_LITERAL(8, 76, 7), // "leading"
QT_MOC_LITERAL(9, 84, 19), // "setGlobalLeadingTop"
QT_MOC_LITERAL(10, 104, 21), // "setGlobalLeadingRight"
QT_MOC_LITERAL(11, 126, 22), // "setGlobalLeadingBottom"
QT_MOC_LITERAL(12, 149, 7), // "setType"
QT_MOC_LITERAL(13, 157, 9), // "ChartType"
QT_MOC_LITERAL(14, 167, 9), // "chartType"
QT_MOC_LITERAL(15, 177, 7), // "SubType"
QT_MOC_LITERAL(16, 185, 7), // "subType"
QT_MOC_LITERAL(17, 193, 10) // "setSubType"

    },
    "KChart::Widget\0setGlobalLeading\0\0left\0"
    "top\0right\0bottom\0setGlobalLeadingLeft\0"
    "leading\0setGlobalLeadingTop\0"
    "setGlobalLeadingRight\0setGlobalLeadingBottom\0"
    "setType\0ChartType\0chartType\0SubType\0"
    "subType\0setSubType"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KChart__Widget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    4,   54,    2, 0x0a /* Public */,
       7,    1,   63,    2, 0x0a /* Public */,
       9,    1,   66,    2, 0x0a /* Public */,
      10,    1,   69,    2, 0x0a /* Public */,
      11,    1,   72,    2, 0x0a /* Public */,
      12,    2,   75,    2, 0x0a /* Public */,
      12,    1,   80,    2, 0x2a /* Public | MethodCloned */,
      17,    1,   83,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    5,    6,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, 0x80000000 | 13, 0x80000000 | 15,   14,   16,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, 0x80000000 | 15,   16,

       0        // eod
};

void KChart::Widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Widget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setGlobalLeading((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 1: _t->setGlobalLeadingLeft((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->setGlobalLeadingTop((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->setGlobalLeadingRight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->setGlobalLeadingBottom((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->setType((*reinterpret_cast< ChartType(*)>(_a[1])),(*reinterpret_cast< SubType(*)>(_a[2]))); break;
        case 6: _t->setType((*reinterpret_cast< ChartType(*)>(_a[1]))); break;
        case 7: _t->setSubType((*reinterpret_cast< SubType(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KChart::Widget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_KChart__Widget.data,
    qt_meta_data_KChart__Widget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KChart::Widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KChart::Widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KChart__Widget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KChart::Widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
