/****************************************************************************
** Meta object code from reading C++ file 'KChartModelDataCache_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdiagram-2.8.0/src/KChart/KChartModelDataCache_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KChartModelDataCache_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KChart__ModelDataCachePrivate__ModelSignalMapperConnector_t {
    QByteArrayData data[11];
    char stringdata0[175];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KChart__ModelDataCachePrivate__ModelSignalMapperConnector_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KChart__ModelDataCachePrivate__ModelSignalMapperConnector_t qt_meta_stringdata_KChart__ModelDataCachePrivate__ModelSignalMapperConnector = {
    {
QT_MOC_LITERAL(0, 0, 57), // "KChart::ModelDataCachePrivate..."
QT_MOC_LITERAL(1, 58, 10), // "resetModel"
QT_MOC_LITERAL(2, 69, 0), // ""
QT_MOC_LITERAL(3, 70, 15), // "columnsInserted"
QT_MOC_LITERAL(4, 86, 11), // "QModelIndex"
QT_MOC_LITERAL(5, 98, 14), // "columnsRemoved"
QT_MOC_LITERAL(6, 113, 11), // "dataChanged"
QT_MOC_LITERAL(7, 125, 13), // "layoutChanged"
QT_MOC_LITERAL(8, 139, 10), // "modelReset"
QT_MOC_LITERAL(9, 150, 12), // "rowsInserted"
QT_MOC_LITERAL(10, 163, 11) // "rowsRemoved"

    },
    "KChart::ModelDataCachePrivate::ModelSignalMapperConnector\0"
    "resetModel\0\0columnsInserted\0QModelIndex\0"
    "columnsRemoved\0dataChanged\0layoutChanged\0"
    "modelReset\0rowsInserted\0rowsRemoved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KChart__ModelDataCachePrivate__ModelSignalMapperConnector[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x09 /* Protected */,
       3,    3,   55,    2, 0x09 /* Protected */,
       5,    3,   62,    2, 0x09 /* Protected */,
       6,    2,   69,    2, 0x09 /* Protected */,
       7,    0,   74,    2, 0x09 /* Protected */,
       8,    0,   75,    2, 0x09 /* Protected */,
       9,    3,   76,    2, 0x09 /* Protected */,
      10,    3,   83,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    2,    2,    2,

       0        // eod
};

void KChart::ModelDataCachePrivate::ModelSignalMapperConnector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ModelSignalMapperConnector *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->resetModel(); break;
        case 1: _t->columnsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 2: _t->columnsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->dataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 4: _t->layoutChanged(); break;
        case 5: _t->modelReset(); break;
        case 6: _t->rowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 7: _t->rowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KChart::ModelDataCachePrivate::ModelSignalMapperConnector::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KChart__ModelDataCachePrivate__ModelSignalMapperConnector.data,
    qt_meta_data_KChart__ModelDataCachePrivate__ModelSignalMapperConnector,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KChart::ModelDataCachePrivate::ModelSignalMapperConnector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KChart::ModelDataCachePrivate::ModelSignalMapperConnector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KChart__ModelDataCachePrivate__ModelSignalMapperConnector.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KChart::ModelDataCachePrivate::ModelSignalMapperConnector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
