/****************************************************************************
** Meta object code from reading C++ file 'kganttgraphicsview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdiagram-2.8.0/src/KGantt/kganttgraphicsview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kganttgraphicsview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KGantt__GraphicsView_t {
    QByteArrayData data[50];
    char stringdata0[728];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KGantt__GraphicsView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KGantt__GraphicsView_t qt_meta_stringdata_KGantt__GraphicsView = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KGantt::GraphicsView"
QT_MOC_LITERAL(1, 21, 9), // "activated"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 44, 5), // "index"
QT_MOC_LITERAL(5, 50, 7), // "clicked"
QT_MOC_LITERAL(6, 58, 12), // "qrealClicked"
QT_MOC_LITERAL(7, 71, 7), // "entered"
QT_MOC_LITERAL(8, 79, 7), // "pressed"
QT_MOC_LITERAL(9, 87, 26), // "headerContextMenuRequested"
QT_MOC_LITERAL(10, 114, 2), // "pt"
QT_MOC_LITERAL(11, 117, 15), // "slotGridChanged"
QT_MOC_LITERAL(12, 133, 32), // "slotHorizontalScrollValueChanged"
QT_MOC_LITERAL(13, 166, 30), // "slotHeaderContextMenuRequested"
QT_MOC_LITERAL(14, 197, 19), // "slotColumnsInserted"
QT_MOC_LITERAL(15, 217, 6), // "parent"
QT_MOC_LITERAL(16, 224, 5), // "start"
QT_MOC_LITERAL(17, 230, 3), // "end"
QT_MOC_LITERAL(18, 234, 18), // "slotColumnsRemoved"
QT_MOC_LITERAL(19, 253, 15), // "slotDataChanged"
QT_MOC_LITERAL(20, 269, 7), // "topLeft"
QT_MOC_LITERAL(21, 277, 11), // "bottomRight"
QT_MOC_LITERAL(22, 289, 17), // "slotLayoutChanged"
QT_MOC_LITERAL(23, 307, 14), // "slotModelReset"
QT_MOC_LITERAL(24, 322, 16), // "slotRowsInserted"
QT_MOC_LITERAL(25, 339, 24), // "slotRowsAboutToBeRemoved"
QT_MOC_LITERAL(26, 364, 15), // "slotRowsRemoved"
QT_MOC_LITERAL(27, 380, 15), // "slotItemClicked"
QT_MOC_LITERAL(28, 396, 3), // "idx"
QT_MOC_LITERAL(29, 400, 21), // "slotItemDoubleClicked"
QT_MOC_LITERAL(30, 422, 15), // "updateSceneRect"
QT_MOC_LITERAL(31, 438, 8), // "setModel"
QT_MOC_LITERAL(32, 447, 19), // "QAbstractItemModel*"
QT_MOC_LITERAL(33, 467, 23), // "setSummaryHandlingModel"
QT_MOC_LITERAL(34, 491, 20), // "QAbstractProxyModel*"
QT_MOC_LITERAL(35, 512, 5), // "model"
QT_MOC_LITERAL(36, 518, 18), // "setConstraintModel"
QT_MOC_LITERAL(37, 537, 16), // "ConstraintModel*"
QT_MOC_LITERAL(38, 554, 12), // "setRootIndex"
QT_MOC_LITERAL(39, 567, 17), // "setSelectionModel"
QT_MOC_LITERAL(40, 585, 20), // "QItemSelectionModel*"
QT_MOC_LITERAL(41, 606, 16), // "setRowController"
QT_MOC_LITERAL(42, 623, 22), // "AbstractRowController*"
QT_MOC_LITERAL(43, 646, 7), // "setGrid"
QT_MOC_LITERAL(44, 654, 13), // "AbstractGrid*"
QT_MOC_LITERAL(45, 668, 15), // "setItemDelegate"
QT_MOC_LITERAL(46, 684, 13), // "ItemDelegate*"
QT_MOC_LITERAL(47, 698, 8), // "delegate"
QT_MOC_LITERAL(48, 707, 11), // "setReadOnly"
QT_MOC_LITERAL(49, 719, 8) // "readOnly"

    },
    "KGantt::GraphicsView\0activated\0\0"
    "QModelIndex\0index\0clicked\0qrealClicked\0"
    "entered\0pressed\0headerContextMenuRequested\0"
    "pt\0slotGridChanged\0slotHorizontalScrollValueChanged\0"
    "slotHeaderContextMenuRequested\0"
    "slotColumnsInserted\0parent\0start\0end\0"
    "slotColumnsRemoved\0slotDataChanged\0"
    "topLeft\0bottomRight\0slotLayoutChanged\0"
    "slotModelReset\0slotRowsInserted\0"
    "slotRowsAboutToBeRemoved\0slotRowsRemoved\0"
    "slotItemClicked\0idx\0slotItemDoubleClicked\0"
    "updateSceneRect\0setModel\0QAbstractItemModel*\0"
    "setSummaryHandlingModel\0QAbstractProxyModel*\0"
    "model\0setConstraintModel\0ConstraintModel*\0"
    "setRootIndex\0setSelectionModel\0"
    "QItemSelectionModel*\0setRowController\0"
    "AbstractRowController*\0setGrid\0"
    "AbstractGrid*\0setItemDelegate\0"
    "ItemDelegate*\0delegate\0setReadOnly\0"
    "readOnly"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KGantt__GraphicsView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       1,  260, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  159,    2, 0x06 /* Public */,
       5,    1,  162,    2, 0x06 /* Public */,
       6,    1,  165,    2, 0x06 /* Public */,
       7,    1,  168,    2, 0x06 /* Public */,
       8,    1,  171,    2, 0x06 /* Public */,
       9,    1,  174,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,  177,    2, 0x08 /* Private */,
      12,    1,  178,    2, 0x08 /* Private */,
      13,    1,  181,    2, 0x08 /* Private */,
      14,    3,  184,    2, 0x08 /* Private */,
      18,    3,  191,    2, 0x08 /* Private */,
      19,    2,  198,    2, 0x08 /* Private */,
      22,    0,  203,    2, 0x08 /* Private */,
      23,    0,  204,    2, 0x08 /* Private */,
      24,    3,  205,    2, 0x08 /* Private */,
      25,    3,  212,    2, 0x08 /* Private */,
      26,    3,  219,    2, 0x08 /* Private */,
      27,    1,  226,    2, 0x08 /* Private */,
      29,    1,  229,    2, 0x08 /* Private */,
      30,    0,  232,    2, 0x0a /* Public */,
      31,    1,  233,    2, 0x0a /* Public */,
      33,    1,  236,    2, 0x0a /* Public */,
      36,    1,  239,    2, 0x0a /* Public */,
      38,    1,  242,    2, 0x0a /* Public */,
      39,    1,  245,    2, 0x0a /* Public */,
      41,    1,  248,    2, 0x0a /* Public */,
      43,    1,  251,    2, 0x0a /* Public */,
      45,    1,  254,    2, 0x0a /* Public */,
      48,    1,  257,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QPoint,   10,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   15,   16,   17,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   15,   16,   17,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,   20,   21,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   15,   16,   17,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   15,   16,   17,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   15,   16,   17,
    QMetaType::Void, 0x80000000 | 3,   28,
    QMetaType::Void, 0x80000000 | 3,   28,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 32,    2,
    QMetaType::Void, 0x80000000 | 34,   35,
    QMetaType::Void, 0x80000000 | 37,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 40,    2,
    QMetaType::Void, 0x80000000 | 42,    2,
    QMetaType::Void, 0x80000000 | 44,    2,
    QMetaType::Void, 0x80000000 | 46,   47,
    QMetaType::Void, QMetaType::Bool,    2,

 // properties: name, type, flags
      49, QMetaType::Bool, 0x00095103,

       0        // eod
};

void KGantt::GraphicsView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<GraphicsView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->activated((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 1: _t->clicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 2: _t->qrealClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 3: _t->entered((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 4: _t->pressed((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 5: _t->headerContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 6: _t->d->slotGridChanged(); break;
        case 7: _t->d->slotHorizontalScrollValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->d->slotHeaderContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 9: _t->d->slotColumnsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 10: _t->d->slotColumnsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 11: _t->d->slotDataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 12: _t->d->slotLayoutChanged(); break;
        case 13: _t->d->slotModelReset(); break;
        case 14: _t->d->slotRowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 15: _t->d->slotRowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 16: _t->d->slotRowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 17: _t->d->slotItemClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 18: _t->d->slotItemDoubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 19: _t->updateSceneRect(); break;
        case 20: _t->setModel((*reinterpret_cast< QAbstractItemModel*(*)>(_a[1]))); break;
        case 21: _t->setSummaryHandlingModel((*reinterpret_cast< QAbstractProxyModel*(*)>(_a[1]))); break;
        case 22: _t->setConstraintModel((*reinterpret_cast< ConstraintModel*(*)>(_a[1]))); break;
        case 23: _t->setRootIndex((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 24: _t->setSelectionModel((*reinterpret_cast< QItemSelectionModel*(*)>(_a[1]))); break;
        case 25: _t->setRowController((*reinterpret_cast< AbstractRowController*(*)>(_a[1]))); break;
        case 26: _t->setGrid((*reinterpret_cast< AbstractGrid*(*)>(_a[1]))); break;
        case 27: _t->setItemDelegate((*reinterpret_cast< ItemDelegate*(*)>(_a[1]))); break;
        case 28: _t->setReadOnly((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (GraphicsView::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsView::activated)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (GraphicsView::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsView::clicked)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (GraphicsView::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsView::qrealClicked)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (GraphicsView::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsView::entered)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (GraphicsView::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsView::pressed)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (GraphicsView::*)(const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GraphicsView::headerContextMenuRequested)) {
                *result = 5;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<GraphicsView *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isReadOnly(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<GraphicsView *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setReadOnly(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KGantt::GraphicsView::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_meta_stringdata_KGantt__GraphicsView.data,
    qt_meta_data_KGantt__GraphicsView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KGantt::GraphicsView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGantt::GraphicsView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KGantt__GraphicsView.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int KGantt::GraphicsView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 29;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KGantt::GraphicsView::activated(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KGantt::GraphicsView::clicked(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KGantt::GraphicsView::qrealClicked(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KGantt::GraphicsView::entered(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KGantt::GraphicsView::pressed(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KGantt::GraphicsView::headerContextMenuRequested(const QPoint & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
