/****************************************************************************
** Meta object code from reading C++ file 'kganttview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdiagram-2.8.0/src/KGantt/kganttview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kganttview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KGantt__View_t {
    QByteArrayData data[25];
    char stringdata0[365];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KGantt__View_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KGantt__View_t qt_meta_stringdata_KGantt__View = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KGantt::View"
QT_MOC_LITERAL(1, 13, 13), // "slotCollapsed"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 40, 12), // "slotExpanded"
QT_MOC_LITERAL(5, 53, 30), // "slotVerticalScrollValueChanged"
QT_MOC_LITERAL(6, 84, 34), // "slotLeftWidgetVerticalRangeCh..."
QT_MOC_LITERAL(7, 119, 31), // "slotGfxViewVerticalRangeChanged"
QT_MOC_LITERAL(8, 151, 8), // "setModel"
QT_MOC_LITERAL(9, 160, 19), // "QAbstractItemModel*"
QT_MOC_LITERAL(10, 180, 5), // "model"
QT_MOC_LITERAL(11, 186, 12), // "setRootIndex"
QT_MOC_LITERAL(12, 199, 3), // "idx"
QT_MOC_LITERAL(13, 203, 17), // "setSelectionModel"
QT_MOC_LITERAL(14, 221, 20), // "QItemSelectionModel*"
QT_MOC_LITERAL(15, 242, 6), // "smodel"
QT_MOC_LITERAL(16, 249, 15), // "setItemDelegate"
QT_MOC_LITERAL(17, 265, 13), // "ItemDelegate*"
QT_MOC_LITERAL(18, 279, 18), // "setConstraintModel"
QT_MOC_LITERAL(19, 298, 16), // "ConstraintModel*"
QT_MOC_LITERAL(20, 315, 7), // "setGrid"
QT_MOC_LITERAL(21, 323, 13), // "AbstractGrid*"
QT_MOC_LITERAL(22, 337, 9), // "expandAll"
QT_MOC_LITERAL(23, 347, 5), // "index"
QT_MOC_LITERAL(24, 353, 11) // "collapseAll"

    },
    "KGantt::View\0slotCollapsed\0\0QModelIndex\0"
    "slotExpanded\0slotVerticalScrollValueChanged\0"
    "slotLeftWidgetVerticalRangeChanged\0"
    "slotGfxViewVerticalRangeChanged\0"
    "setModel\0QAbstractItemModel*\0model\0"
    "setRootIndex\0idx\0setSelectionModel\0"
    "QItemSelectionModel*\0smodel\0setItemDelegate\0"
    "ItemDelegate*\0setConstraintModel\0"
    "ConstraintModel*\0setGrid\0AbstractGrid*\0"
    "expandAll\0index\0collapseAll"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KGantt__View[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   89,    2, 0x08 /* Private */,
       4,    1,   92,    2, 0x08 /* Private */,
       5,    1,   95,    2, 0x08 /* Private */,
       6,    2,   98,    2, 0x08 /* Private */,
       7,    2,  103,    2, 0x08 /* Private */,
       8,    1,  108,    2, 0x0a /* Public */,
      11,    1,  111,    2, 0x0a /* Public */,
      13,    1,  114,    2, 0x0a /* Public */,
      16,    1,  117,    2, 0x0a /* Public */,
      18,    1,  120,    2, 0x0a /* Public */,
      20,    1,  123,    2, 0x0a /* Public */,
      22,    1,  126,    2, 0x0a /* Public */,
      22,    0,  129,    2, 0x2a /* Public | MethodCloned */,
      24,    1,  130,    2, 0x0a /* Public */,
      24,    0,  133,    2, 0x2a /* Public | MethodCloned */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 3,   12,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 17,    2,
    QMetaType::Void, 0x80000000 | 19,    2,
    QMetaType::Void, 0x80000000 | 21,    2,
    QMetaType::Void, 0x80000000 | 3,   23,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,   23,
    QMetaType::Void,

       0        // eod
};

void KGantt::View::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<View *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->d->slotCollapsed((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 1: _t->d->slotExpanded((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 2: _t->d->slotVerticalScrollValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->d->slotLeftWidgetVerticalRangeChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->d->slotGfxViewVerticalRangeChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->setModel((*reinterpret_cast< QAbstractItemModel*(*)>(_a[1]))); break;
        case 6: _t->setRootIndex((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 7: _t->setSelectionModel((*reinterpret_cast< QItemSelectionModel*(*)>(_a[1]))); break;
        case 8: _t->setItemDelegate((*reinterpret_cast< ItemDelegate*(*)>(_a[1]))); break;
        case 9: _t->setConstraintModel((*reinterpret_cast< ConstraintModel*(*)>(_a[1]))); break;
        case 10: _t->setGrid((*reinterpret_cast< AbstractGrid*(*)>(_a[1]))); break;
        case 11: _t->expandAll((*reinterpret_cast< QModelIndex(*)>(_a[1]))); break;
        case 12: _t->expandAll(); break;
        case 13: _t->collapseAll((*reinterpret_cast< QModelIndex(*)>(_a[1]))); break;
        case 14: _t->collapseAll(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KGantt::View::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_KGantt__View.data,
    qt_meta_data_KGantt__View,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KGantt::View::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGantt::View::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KGantt__View.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KGantt::View::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
