/****************************************************************************
** Meta object code from reading C++ file 'KChartCartesianDiagramDataCompressor_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdiagram-2.8.0/src/KChart/Cartesian/KChartCartesianDiagramDataCompressor_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KChartCartesianDiagramDataCompressor_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KChart__CartesianDiagramDataCompressor_t {
    QByteArrayData data[19];
    char stringdata0[385];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KChart__CartesianDiagramDataCompressor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KChart__CartesianDiagramDataCompressor_t qt_meta_stringdata_KChart__CartesianDiagramDataCompressor = {
    {
QT_MOC_LITERAL(0, 0, 38), // "KChart::CartesianDiagramDataC..."
QT_MOC_LITERAL(1, 39, 25), // "slotRowsAboutToBeInserted"
QT_MOC_LITERAL(2, 65, 0), // ""
QT_MOC_LITERAL(3, 66, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 78, 16), // "slotRowsInserted"
QT_MOC_LITERAL(5, 95, 24), // "slotRowsAboutToBeRemoved"
QT_MOC_LITERAL(6, 120, 15), // "slotRowsRemoved"
QT_MOC_LITERAL(7, 136, 28), // "slotColumnsAboutToBeInserted"
QT_MOC_LITERAL(8, 165, 19), // "slotColumnsInserted"
QT_MOC_LITERAL(9, 185, 27), // "slotColumnsAboutToBeRemoved"
QT_MOC_LITERAL(10, 213, 18), // "slotColumnsRemoved"
QT_MOC_LITERAL(11, 232, 26), // "slotModelHeaderDataChanged"
QT_MOC_LITERAL(12, 259, 15), // "Qt::Orientation"
QT_MOC_LITERAL(13, 275, 20), // "slotModelDataChanged"
QT_MOC_LITERAL(14, 296, 22), // "slotModelLayoutChanged"
QT_MOC_LITERAL(15, 319, 24), // "slotDiagramLayoutChanged"
QT_MOC_LITERAL(16, 344, 16), // "AbstractDiagram*"
QT_MOC_LITERAL(17, 361, 12), // "rebuildCache"
QT_MOC_LITERAL(18, 374, 10) // "clearCache"

    },
    "KChart::CartesianDiagramDataCompressor\0"
    "slotRowsAboutToBeInserted\0\0QModelIndex\0"
    "slotRowsInserted\0slotRowsAboutToBeRemoved\0"
    "slotRowsRemoved\0slotColumnsAboutToBeInserted\0"
    "slotColumnsInserted\0slotColumnsAboutToBeRemoved\0"
    "slotColumnsRemoved\0slotModelHeaderDataChanged\0"
    "Qt::Orientation\0slotModelDataChanged\0"
    "slotModelLayoutChanged\0slotDiagramLayoutChanged\0"
    "AbstractDiagram*\0rebuildCache\0clearCache"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KChart__CartesianDiagramDataCompressor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    3,   84,    2, 0x08 /* Private */,
       4,    3,   91,    2, 0x08 /* Private */,
       5,    3,   98,    2, 0x08 /* Private */,
       6,    3,  105,    2, 0x08 /* Private */,
       7,    3,  112,    2, 0x08 /* Private */,
       8,    3,  119,    2, 0x08 /* Private */,
       9,    3,  126,    2, 0x08 /* Private */,
      10,    3,  133,    2, 0x08 /* Private */,
      11,    3,  140,    2, 0x08 /* Private */,
      13,    2,  147,    2, 0x08 /* Private */,
      14,    0,  152,    2, 0x08 /* Private */,
      15,    1,  153,    2, 0x08 /* Private */,
      17,    0,  156,    2, 0x08 /* Private */,
      18,    0,  157,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 12, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    2,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KChart::CartesianDiagramDataCompressor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CartesianDiagramDataCompressor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotRowsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 1: _t->slotRowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 2: _t->slotRowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->slotRowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->slotColumnsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 5: _t->slotColumnsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 6: _t->slotColumnsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 7: _t->slotColumnsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 8: _t->slotModelHeaderDataChanged((*reinterpret_cast< Qt::Orientation(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 9: _t->slotModelDataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 10: _t->slotModelLayoutChanged(); break;
        case 11: _t->slotDiagramLayoutChanged((*reinterpret_cast< AbstractDiagram*(*)>(_a[1]))); break;
        case 12: _t->rebuildCache(); break;
        case 13: _t->clearCache(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KChart::CartesianDiagramDataCompressor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KChart__CartesianDiagramDataCompressor.data,
    qt_meta_data_KChart__CartesianDiagramDataCompressor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KChart::CartesianDiagramDataCompressor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KChart::CartesianDiagramDataCompressor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KChart__CartesianDiagramDataCompressor.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KChart::CartesianDiagramDataCompressor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
