/****************************************************************************
** Meta object code from reading C++ file 'KChartAbstractDiagram.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdiagram-2.8.0/src/KChart/KChartAbstractDiagram.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KChartAbstractDiagram.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KChart__AbstractDiagram_t {
    QByteArrayData data[16];
    char stringdata0[272];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KChart__AbstractDiagram_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KChart__AbstractDiagram_t qt_meta_stringdata_KChart__AbstractDiagram = {
    {
QT_MOC_LITERAL(0, 0, 23), // "KChart::AbstractDiagram"
QT_MOC_LITERAL(1, 24, 13), // "layoutChanged"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 16), // "AbstractDiagram*"
QT_MOC_LITERAL(4, 56, 18), // "aboutToBeDestroyed"
QT_MOC_LITERAL(5, 75, 13), // "modelsChanged"
QT_MOC_LITERAL(6, 89, 28), // "attributesModelAboutToChange"
QT_MOC_LITERAL(7, 118, 16), // "AttributesModel*"
QT_MOC_LITERAL(8, 135, 8), // "newModel"
QT_MOC_LITERAL(9, 144, 8), // "oldModel"
QT_MOC_LITERAL(10, 153, 16), // "modelDataChanged"
QT_MOC_LITERAL(11, 170, 10), // "dataHidden"
QT_MOC_LITERAL(12, 181, 17), // "propertiesChanged"
QT_MOC_LITERAL(13, 199, 17), // "boundariesChanged"
QT_MOC_LITERAL(14, 217, 31), // "viewportCoordinateSystemChanged"
QT_MOC_LITERAL(15, 249, 22) // "setDataBoundariesDirty"

    },
    "KChart::AbstractDiagram\0layoutChanged\0"
    "\0AbstractDiagram*\0aboutToBeDestroyed\0"
    "modelsChanged\0attributesModelAboutToChange\0"
    "AttributesModel*\0newModel\0oldModel\0"
    "modelDataChanged\0dataHidden\0"
    "propertiesChanged\0boundariesChanged\0"
    "viewportCoordinateSystemChanged\0"
    "setDataBoundariesDirty"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KChart__AbstractDiagram[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    0,   67,    2, 0x06 /* Public */,
       5,    0,   68,    2, 0x06 /* Public */,
       6,    2,   69,    2, 0x06 /* Public */,
      10,    0,   74,    2, 0x06 /* Public */,
      11,    0,   75,    2, 0x06 /* Public */,
      12,    0,   76,    2, 0x06 /* Public */,
      13,    0,   77,    2, 0x06 /* Public */,
      14,    0,   78,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      15,    0,   79,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 7,    8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void KChart::AbstractDiagram::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AbstractDiagram *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->layoutChanged((*reinterpret_cast< AbstractDiagram*(*)>(_a[1]))); break;
        case 1: _t->aboutToBeDestroyed(); break;
        case 2: _t->modelsChanged(); break;
        case 3: _t->attributesModelAboutToChange((*reinterpret_cast< AttributesModel*(*)>(_a[1])),(*reinterpret_cast< AttributesModel*(*)>(_a[2]))); break;
        case 4: _t->modelDataChanged(); break;
        case 5: _t->dataHidden(); break;
        case 6: _t->propertiesChanged(); break;
        case 7: _t->boundariesChanged(); break;
        case 8: _t->viewportCoordinateSystemChanged(); break;
        case 9: _t->setDataBoundariesDirty(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AbstractDiagram* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AttributesModel* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (AbstractDiagram::*)(AbstractDiagram * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractDiagram::layoutChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (AbstractDiagram::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractDiagram::aboutToBeDestroyed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (AbstractDiagram::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractDiagram::modelsChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (AbstractDiagram::*)(AttributesModel * , AttributesModel * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractDiagram::attributesModelAboutToChange)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (AbstractDiagram::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractDiagram::modelDataChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (AbstractDiagram::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractDiagram::dataHidden)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (AbstractDiagram::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractDiagram::propertiesChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (AbstractDiagram::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractDiagram::boundariesChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (AbstractDiagram::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractDiagram::viewportCoordinateSystemChanged)) {
                *result = 8;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KChart::AbstractDiagram::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemView::staticMetaObject>(),
    qt_meta_stringdata_KChart__AbstractDiagram.data,
    qt_meta_data_KChart__AbstractDiagram,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KChart::AbstractDiagram::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KChart::AbstractDiagram::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KChart__AbstractDiagram.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemView::qt_metacast(_clname);
}

int KChart::AbstractDiagram::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KChart::AbstractDiagram::layoutChanged(AbstractDiagram * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KChart::AbstractDiagram::aboutToBeDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KChart::AbstractDiagram::modelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KChart::AbstractDiagram::attributesModelAboutToChange(AttributesModel * _t1, AttributesModel * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KChart::AbstractDiagram::modelDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KChart::AbstractDiagram::dataHidden()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KChart::AbstractDiagram::propertiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KChart::AbstractDiagram::boundariesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KChart::AbstractDiagram::viewportCoordinateSystemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
struct qt_meta_stringdata_KChart__PrivateAttributesModel_t {
    QByteArrayData data[1];
    char stringdata0[31];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KChart__PrivateAttributesModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KChart__PrivateAttributesModel_t qt_meta_stringdata_KChart__PrivateAttributesModel = {
    {
QT_MOC_LITERAL(0, 0, 30) // "KChart::PrivateAttributesModel"

    },
    "KChart::PrivateAttributesModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KChart__PrivateAttributesModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KChart::PrivateAttributesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KChart::PrivateAttributesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AttributesModel::staticMetaObject>(),
    qt_meta_stringdata_KChart__PrivateAttributesModel.data,
    qt_meta_data_KChart__PrivateAttributesModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KChart::PrivateAttributesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KChart::PrivateAttributesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KChart__PrivateAttributesModel.stringdata0))
        return static_cast<void*>(this);
    return AttributesModel::qt_metacast(_clname);
}

int KChart::PrivateAttributesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AttributesModel::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
