/****************************************************************************
** Meta object code from reading C++ file 'KChartEnums.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../kdiagram-2.8.0/src/KChart/KChartEnums.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KChartEnums.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KChartEnums_t {
    QByteArrayData data[37];
    char stringdata0[826];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KChartEnums_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KChartEnums_t qt_meta_stringdata_KChartEnums = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KChartEnums"
QT_MOC_LITERAL(1, 12, 19), // "GranularitySequence"
QT_MOC_LITERAL(2, 32, 25), // "GranularitySequence_10_20"
QT_MOC_LITERAL(3, 58, 25), // "GranularitySequence_10_50"
QT_MOC_LITERAL(4, 84, 25), // "GranularitySequence_25_50"
QT_MOC_LITERAL(5, 110, 26), // "GranularitySequence_125_25"
QT_MOC_LITERAL(6, 137, 28), // "GranularitySequenceIrregular"
QT_MOC_LITERAL(7, 166, 16), // "TextLayoutPolicy"
QT_MOC_LITERAL(8, 183, 19), // "LayoutJustOverwrite"
QT_MOC_LITERAL(9, 203, 18), // "LayoutPolicyRotate"
QT_MOC_LITERAL(10, 222, 27), // "LayoutPolicyShiftVertically"
QT_MOC_LITERAL(11, 250, 29), // "LayoutPolicyShiftHorizontally"
QT_MOC_LITERAL(12, 280, 26), // "LayoutPolicyShrinkFontSize"
QT_MOC_LITERAL(13, 307, 13), // "PositionValue"
QT_MOC_LITERAL(14, 321, 15), // "PositionUnknown"
QT_MOC_LITERAL(15, 337, 14), // "PositionCenter"
QT_MOC_LITERAL(16, 352, 17), // "PositionNorthWest"
QT_MOC_LITERAL(17, 370, 13), // "PositionNorth"
QT_MOC_LITERAL(18, 384, 17), // "PositionNorthEast"
QT_MOC_LITERAL(19, 402, 12), // "PositionEast"
QT_MOC_LITERAL(20, 415, 17), // "PositionSouthEast"
QT_MOC_LITERAL(21, 433, 13), // "PositionSouth"
QT_MOC_LITERAL(22, 447, 17), // "PositionSouthWest"
QT_MOC_LITERAL(23, 465, 12), // "PositionWest"
QT_MOC_LITERAL(24, 478, 16), // "PositionFloating"
QT_MOC_LITERAL(25, 495, 22), // "MeasureCalculationMode"
QT_MOC_LITERAL(26, 518, 30), // "MeasureCalculationModeAbsolute"
QT_MOC_LITERAL(27, 549, 30), // "MeasureCalculationModeRelative"
QT_MOC_LITERAL(28, 580, 26), // "MeasureCalculationModeAuto"
QT_MOC_LITERAL(29, 607, 30), // "MeasureCalculationModeAutoArea"
QT_MOC_LITERAL(30, 638, 37), // "MeasureCalculationModeAutoOri..."
QT_MOC_LITERAL(31, 676, 18), // "MeasureOrientation"
QT_MOC_LITERAL(32, 695, 22), // "MeasureOrientationAuto"
QT_MOC_LITERAL(33, 718, 28), // "MeasureOrientationHorizontal"
QT_MOC_LITERAL(34, 747, 26), // "MeasureOrientationVertical"
QT_MOC_LITERAL(35, 774, 25), // "MeasureOrientationMinimum"
QT_MOC_LITERAL(36, 800, 25) // "MeasureOrientationMaximum"

    },
    "KChartEnums\0GranularitySequence\0"
    "GranularitySequence_10_20\0"
    "GranularitySequence_10_50\0"
    "GranularitySequence_25_50\0"
    "GranularitySequence_125_25\0"
    "GranularitySequenceIrregular\0"
    "TextLayoutPolicy\0LayoutJustOverwrite\0"
    "LayoutPolicyRotate\0LayoutPolicyShiftVertically\0"
    "LayoutPolicyShiftHorizontally\0"
    "LayoutPolicyShrinkFontSize\0PositionValue\0"
    "PositionUnknown\0PositionCenter\0"
    "PositionNorthWest\0PositionNorth\0"
    "PositionNorthEast\0PositionEast\0"
    "PositionSouthEast\0PositionSouth\0"
    "PositionSouthWest\0PositionWest\0"
    "PositionFloating\0MeasureCalculationMode\0"
    "MeasureCalculationModeAbsolute\0"
    "MeasureCalculationModeRelative\0"
    "MeasureCalculationModeAuto\0"
    "MeasureCalculationModeAutoArea\0"
    "MeasureCalculationModeAutoOrientation\0"
    "MeasureOrientation\0MeasureOrientationAuto\0"
    "MeasureOrientationHorizontal\0"
    "MeasureOrientationVertical\0"
    "MeasureOrientationMinimum\0"
    "MeasureOrientationMaximum"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KChartEnums[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       5,   14, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // enums: name, alias, flags, count, data
       1,    1, 0x0,    5,   39,
       7,    7, 0x0,    5,   49,
      13,   13, 0x0,   11,   59,
      25,   25, 0x0,    5,   81,
      31,   31, 0x0,    5,   91,

 // enum data: key, value
       2, uint(KChartEnums::GranularitySequence_10_20),
       3, uint(KChartEnums::GranularitySequence_10_50),
       4, uint(KChartEnums::GranularitySequence_25_50),
       5, uint(KChartEnums::GranularitySequence_125_25),
       6, uint(KChartEnums::GranularitySequenceIrregular),
       8, uint(KChartEnums::LayoutJustOverwrite),
       9, uint(KChartEnums::LayoutPolicyRotate),
      10, uint(KChartEnums::LayoutPolicyShiftVertically),
      11, uint(KChartEnums::LayoutPolicyShiftHorizontally),
      12, uint(KChartEnums::LayoutPolicyShrinkFontSize),
      14, uint(KChartEnums::PositionUnknown),
      15, uint(KChartEnums::PositionCenter),
      16, uint(KChartEnums::PositionNorthWest),
      17, uint(KChartEnums::PositionNorth),
      18, uint(KChartEnums::PositionNorthEast),
      19, uint(KChartEnums::PositionEast),
      20, uint(KChartEnums::PositionSouthEast),
      21, uint(KChartEnums::PositionSouth),
      22, uint(KChartEnums::PositionSouthWest),
      23, uint(KChartEnums::PositionWest),
      24, uint(KChartEnums::PositionFloating),
      26, uint(KChartEnums::MeasureCalculationModeAbsolute),
      27, uint(KChartEnums::MeasureCalculationModeRelative),
      28, uint(KChartEnums::MeasureCalculationModeAuto),
      29, uint(KChartEnums::MeasureCalculationModeAutoArea),
      30, uint(KChartEnums::MeasureCalculationModeAutoOrientation),
      32, uint(KChartEnums::MeasureOrientationAuto),
      33, uint(KChartEnums::MeasureOrientationHorizontal),
      34, uint(KChartEnums::MeasureOrientationVertical),
      35, uint(KChartEnums::MeasureOrientationMinimum),
      36, uint(KChartEnums::MeasureOrientationMaximum),

       0        // eod
};

void KChartEnums::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KChartEnums::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KChartEnums.data,
    qt_meta_data_KChartEnums,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KChartEnums::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KChartEnums::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KChartEnums.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KChartEnums::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
